@@ -10,7 +10,7 @@
 #******************************************************************************************
 #******************************************************************************************
 
-lingpg <- function(inc, gender = NULL, id, weight=NULL, sort = NULL,
+lingpg <- function(Y, gender = NULL, id, weight=NULL, sort = NULL,
                    Dom = NULL, period=NULL, dataset = NULL,
                    var_name="lin_gpg") {
 
@@ -23,7 +23,7 @@ lingpg <- function(inc, gender = NULL, id, weight=NULL, sort = NULL,
 
    if (!is.null(dataset)) {
         dataset <- data.frame(dataset)
-        if (checker(inc, dataset, "inc")) inc <- dataset[, inc] 
+        if (checker(Y, dataset, "Y")) Y <- dataset[, Y] 
         if (checker(gender, dataset, "gender")) gender <- dataset[, gender]  
 
         if (!is.null(id)) {
@@ -52,24 +52,24 @@ lingpg <- function(inc, gender = NULL, id, weight=NULL, sort = NULL,
       }
 
    # check vectors
-   # inc
-   inc <- data.frame(inc)
-   n <- nrow(inc)
-   if (ncol(inc) != 1) stop("'inc' must be vector or 1 column data.frame, matrix, data.table")
-   inc <- inc[,1]
-   if(!is.numeric(inc)) stop("'inc' must be a numeric vector")                   
-   if (any(is.na(inc))) stop("'inc' has unknown values")
+   # Y
+   Y <- data.frame(Y)
+   n <- nrow(Y)
+   if (ncol(Y) != 1) stop("'Y' must be vector or 1 column data.frame, matrix, data.table")
+   Y <- Y[,1]
+   if(!is.numeric(Y)) stop("'Y' must be a numeric vector")                   
+   if (any(is.na(Y))) stop("'Y' has unknown values")
 
    # gender
    if (!is.numeric(gender)) stop("'gender' must be numerical")
-   if (length(gender) != n) stop("'gender' must be the same length as 'inc'")
+   if (length(gender) != n) stop("'gender' must be the same length as 'Y'")
    if (length(unique(gender)) != 2) stop("'gender' must be exactly two values")
    if (!all.equal(unique(gender),c(1, 2))) stop("'gender' must be value 1 for male, 2 for females")
  
    # weight
    weight <- data.frame(weight)
    if (is.null(weight)) weight <- data.frame(rep.int(1, n))
-   if (nrow(weight) != n) stop("'weight' must be the same length as 'inc'")
+   if (nrow(weight) != n) stop("'weight' must be the same length as 'Y'")
    if (ncol(weight) != 1) stop("'weight' must be vector or 1 column data.frame, matrix, data.table")
    weight <- weight[,1]
    if (!is.numeric(weight)) stop("'weight' must be a numerical")
@@ -78,7 +78,7 @@ lingpg <- function(inc, gender = NULL, id, weight=NULL, sort = NULL,
    # sort
    if (!is.null(sort) && !is.vector(sort) && !is.ordered(sort)) {
          stop("'sort' must be a vector or ordered factor") }
-   if (!is.null(sort) && length(sort) != n) stop("'sort' must have the same length as 'inc'")     
+   if (!is.null(sort) && length(sort) != n) stop("'sort' must have the same length as 'Y'")     
    
    # period     
    if (!is.null(period)) {
@@ -86,7 +86,7 @@ lingpg <- function(inc, gender = NULL, id, weight=NULL, sort = NULL,
        if (any(duplicated(names(period)))) 
                  stop("'period' are duplicate column names: ", 
                       paste(names(period)[duplicated(names(period))], collapse = ","))
-       if (nrow(period) != n) stop("'period' must be the same length as 'inc'")
+       if (nrow(period) != n) stop("'period' must be the same length as 'Y'")
        if(any(is.na(period))) stop("'period' has unknown values")  
    }
 
@@ -95,7 +95,7 @@ lingpg <- function(inc, gender = NULL, id, weight=NULL, sort = NULL,
    id <- data.table(id)
    if (any(is.na(id))) stop("'id' has unknown values")
    if (ncol(id) != 1) stop("'id' must be 1 column data.frame, matrix, data.table")
-   if (nrow(id) != n) stop("'id' must be the same length as 'inc'")
+   if (nrow(id) != n) stop("'id' must be the same length as 'Y'")
    if (is.null(names(id))||(names(id)=="id")) setnames(id,names(id),"ID")
    if (is.null(period)){ if (any(duplicated(id))) stop("'id' are duplicate values") 
                        } else {
@@ -110,7 +110,8 @@ lingpg <- function(inc, gender = NULL, id, weight=NULL, sort = NULL,
                  stop("'Dom' are duplicate column names: ", 
                       paste(names(Dom)[duplicated(names(Dom))], collapse = ","))
              if (is.null(names(Dom))) stop("'Dom' must be colnames")
-             if (nrow(Dom) != n) stop("'Dom' must be the same length as 'inc'")
+             if (nrow(Dom) != n) stop("'Dom' must be the same length as 'Y'")
+             Dom <- Dom[, lapply(.SD, as.character), .SDcols = names(Dom)]
        }
 
 
@@ -143,7 +144,7 @@ lingpg <- function(inc, gender = NULL, id, weight=NULL, sort = NULL,
                  if (!is.null(period)) { rown <- cbind(period_agg[j], Dom_agg[i])
                                      } else rown <- Dom_agg[i] 
                  if (!all(indj)) {
-                      gpgl <- linGapCalc(x=inc[indj], gend=gender[indj],
+                      gpgl <- linGapCalc(x=Y[indj], gend=gender[indj],
                                          ids=gpg_id[indj], weights=weight[indj],
                                          sort=sort[indj])
                       list(data.table(rown, gpg=gpgl$gpg_pr), gpgl$lin)
@@ -168,7 +169,7 @@ lingpg <- function(inc, gender = NULL, id, weight=NULL, sort = NULL,
                                        } else rown <- quantile
                            indj <- (rowSums(period1 == period1_agg[j,][ind0,]) == ncol(period1))
       
-                           gpg_l <- linGapCalc(x=inc[indj], gend=gender[indj],
+                           gpg_l <- linGapCalc(x=Y[indj], gend=gender[indj],
                                                ids=gpg_id[indj], weights=weight[indj],
                                                sort=sort[indj])
 
